@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c,v 1.138 2006/04/20 10:40:46 sfre Exp $
+ * $Id: gedit.c,v 1.140 2006/05/29 10:14:28 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -87,7 +87,7 @@ static const GOptionEntry options [] =
 };
 
 static void
-gedit_get_command_line_data (GnomeProgram *program)
+gedit_get_command_line_data (void)
 {
 	if (remaining_args)
 	{
@@ -228,8 +228,7 @@ on_message_received (const char *message,
 	g_strfreev (params);
 
 	/* body */
-	i = 1;
-	while (commands[i])
+	for (i = 1; commands[i] != NULL; i++)
 	{
 		params = g_strsplit (commands[i], "\t", -1);
 
@@ -243,7 +242,7 @@ on_message_received (const char *message,
 		}
 		else if (strcmp (params[0], "OPEN-URIS") == 0)
 		{
-			gint n_uris, i;
+			gint n_uris, j;
 			gchar **uris;
 
 			line_position = atoi (params[1]);
@@ -253,8 +252,8 @@ on_message_received (const char *message,
 			n_uris = atoi (params[3]);
 			uris = g_strsplit (params[4], " ", n_uris);
 
-			for (i = 0; i < n_uris; i++)
-				file_list = g_slist_prepend (file_list, uris[i]);
+			for (j = 0; j < n_uris; j++)
+				file_list = g_slist_prepend (file_list, uris[j]);
 			file_list = g_slist_reverse (file_list);
 
 			/* the list takes ownerhip of the strings,
@@ -267,7 +266,6 @@ on_message_received (const char *message,
 		}
 
 		g_strfreev (params);
-		++i;
 	}
 
 	g_strfreev (commands);
@@ -290,10 +288,10 @@ on_message_received (const char *message,
 
 	if (file_list != NULL)
 	{
-		gedit_cmd_load_files_from_prompt (window,
-						  file_list,
-						  encoding,
-						  line_position);
+		_gedit_cmd_load_files_from_prompt (window,
+						   file_list,
+						   encoding,
+						   line_position);
 
 		if (new_document_option)
 			gedit_window_create_tab (window, TRUE);
@@ -404,7 +402,7 @@ send_bacon_message (void)
 		command = g_string_append (command, "OPEN-URIS");
 
 		g_string_append_printf (command,
-					"\t%d\t%s\t%d\t",
+					"\t%d\t%s\t%u\t",
 					line_position,
 					encoding_charset ? encoding_charset : "",
 					g_slist_length (file_list));
@@ -473,7 +471,7 @@ main (int argc, char *argv[])
 		{
 			gedit_debug_message (DEBUG_APP, "I'm a client");
 
-			gedit_get_command_line_data (program);
+			gedit_get_command_line_data ();
 
 			send_bacon_message ();
 
@@ -531,7 +529,7 @@ main (int argc, char *argv[])
 	if (!restored)
 	{
 		gedit_debug_message (DEBUG_APP, "Analyze command line data");
-		gedit_get_command_line_data (program);
+		gedit_get_command_line_data ();
 		
 		gedit_debug_message (DEBUG_APP, "Get default app");
 		app = gedit_app_get_default ();
@@ -542,7 +540,10 @@ main (int argc, char *argv[])
 		if (file_list != NULL)
 		{
 			gedit_debug_message (DEBUG_APP, "Load files");
-			gedit_cmd_load_files_from_prompt (window, file_list, encoding, line_position);
+			_gedit_cmd_load_files_from_prompt (window, 
+							   file_list, 
+							   encoding, 
+							   line_position);
 		}
 		else
 		{
